/* chealpix.h
 *
 */

#ifndef __CHEALPIX_H__
#define __CHEALPIX_H__

/* -------------------- */
/* Constant Definitions */
/* -------------------- */

#ifndef HEALPIX_NULLVAL
#define HEALPIX_NULLVAL (-1.6375e30)
#endif /* HEALPIX_NULLVAL */

/* Function definitions for 'c' */
#ifndef __cplusplus
/* --------------------- */
/* Function Declarations */
/* --------------------- */

/* pixel operations */
/* ---------------- */
void ang2pix_nest(const long nside, double theta, double phi, long *ipix);
void ang2pix_ring(const long nside, double theta, double phi, long *ipix);

void pix2ang_nest(long nside, long ipix, double *theta, double *phi);
void pix2ang_ring(long nside, long ipix, double *theta, double *phi);

void nest2ring(long nside, long ipnest, long *ipring);
void ring2nest(long nside, long ipring, long *ipnest);

void mk_pix2xy(int *pix2x, int *pix2y);
void mk_xy2pix(int *x2pix, int *y2pix);

long nside2npix(const long nside);

/* FITS operations */
/* --------------- */

void printerror (int) ;

float *read_healpix_map (char *, long *, char *, char *) ;

int write_healpix_map( float *, long , char *, char ,char *) ;

long get_fits_size(char *, long *, char * ) ;
#endif

/* Function definitions for 'c++' */
/* Mods by Nicholas Phillips, phillips@friday.gsfc.nasa.gov */
#ifdef __cplusplus
/* pixel operations */
/* ---------------- */
extern "C" void ang2pix_nest(const long nside, double theta, double phi, long *ipix);
extern "C" void ang2pix_ring(const long nside, double theta, double phi, long *ipix);

extern "C" void pix2ang_nest(long nside, long ipix, double *theta, double *phi);
extern "C" void pix2ang_ring(long nside, long ipix, double *theta, double *phi);

extern "C" void nest2ring(long nside, long ipnest, long *ipring);
extern "C" void ring2nest(long nside, long ipring, long *ipnest);

extern "C" void mk_pix2xy(int *pix2x, int *pix2y);
extern "C" void mk_xy2pix(int *x2pix, int *y2pix);

extern "C" long nside2npix(const long nside);

/* FITS operations */
/* --------------- */

extern "C" void printerror (int) ;

extern "C" float *read_healpix_map (char *, long *, char *, char *) ;

extern "C" int write_healpix_map( float *, long , char *, char ,char *) ;

extern "C" long get_fits_size(char *, long *, char * ) ;
#endif

/* ------------------ */
/* end of header file */
/* ------------------ */

#endif /* __CHEALPIX_H__ */

